You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@synapse.apache.org by ru...@apache.org on 2007/09/17 13:10:17 UTC

svn commit: r576367 - in /webservices/synapse/trunk/java/modules: core/src/main/java/org/apache/synapse/core/axis2/ core/src/main/resources/ handler/src/main/java/org/apache/synapse/handler/

Author: ruwan
Date: Mon Sep 17 04:10:10 2007
New Revision: 576367

URL: http://svn.apache.org/viewvc?rev=576367&view=rev
Log:
Renamed the org.apache.synapse.core.axis2.SynapseModule to SynapseInitializationModule due to the possible conflicts with the org.apache.synapse.handler.SynapseModule

Added:
    webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java   (contents, props changed)
      - copied, changed from r576329, webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseModule.java
Removed:
    webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseModule.java
Modified:
    webservices/synapse/trunk/java/modules/core/src/main/resources/module.xml
    webservices/synapse/trunk/java/modules/handler/src/main/java/org/apache/synapse/handler/SynapseModule.java

Copied: webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java (from r576329, webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseModule.java)
URL: http://svn.apache.org/viewvc/webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java?p2=webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java&p1=webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseModule.java&r1=576329&r2=576367&rev=576367&view=diff
==============================================================================
--- webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseModule.java (original)
+++ webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java Mon Sep 17 04:10:10 2007
@@ -20,12 +20,9 @@
 package org.apache.synapse.core.axis2;
 
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.deployment.DeploymentEngine;
-import org.apache.axis2.addressing.AddressingConstants;
 import org.apache.axis2.context.ConfigurationContext;
 import org.apache.axis2.description.*;
 import org.apache.axis2.engine.AxisConfiguration;
-import org.apache.axis2.engine.AxisConfigurator;
 import org.apache.axis2.modules.Module;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -38,8 +35,6 @@
 import org.apache.synapse.config.SynapseConfigurationBuilder;
 
 import javax.xml.namespace.QName;
-import java.lang.reflect.Constructor;
-import java.lang.reflect.InvocationTargetException;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Iterator;
@@ -50,9 +45,9 @@
  * This is the Synapse Module implementation class, which would initialize Synapse when it is
  * deployed onto an Axis2 configuration.
  */
-public class SynapseModule implements Module {
+public class SynapseInitializationModule implements Module {
 
-    private static final Log log = LogFactory.getLog(SynapseModule.class);
+    private static final Log log = LogFactory.getLog(SynapseInitializationModule.class);
 
     private static final String SYNAPSE_SERVICE_NAME = "synapse";
     private static final QName MEDIATE_OPERATION_Q_NAME = new QName("mediate");

Propchange: webservices/synapse/trunk/java/modules/core/src/main/java/org/apache/synapse/core/axis2/SynapseInitializationModule.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: webservices/synapse/trunk/java/modules/core/src/main/resources/module.xml
URL: http://svn.apache.org/viewvc/webservices/synapse/trunk/java/modules/core/src/main/resources/module.xml?rev=576367&r1=576366&r2=576367&view=diff
==============================================================================
--- webservices/synapse/trunk/java/modules/core/src/main/resources/module.xml (original)
+++ webservices/synapse/trunk/java/modules/core/src/main/resources/module.xml Mon Sep 17 04:10:10 2007
@@ -17,7 +17,7 @@
   ~  under the License.
   -->
 
-<module name="synapse" class="org.apache.synapse.core.axis2.SynapseModule">
+<module name="synapse" class="org.apache.synapse.core.axis2.SynapseInitializationModule">
 
     <Description>
         This module dynamically set the Synapse dispatcher. Synapse service and

Modified: webservices/synapse/trunk/java/modules/handler/src/main/java/org/apache/synapse/handler/SynapseModule.java
URL: http://svn.apache.org/viewvc/webservices/synapse/trunk/java/modules/handler/src/main/java/org/apache/synapse/handler/SynapseModule.java?rev=576367&r1=576366&r2=576367&view=diff
==============================================================================
--- webservices/synapse/trunk/java/modules/handler/src/main/java/org/apache/synapse/handler/SynapseModule.java (original)
+++ webservices/synapse/trunk/java/modules/handler/src/main/java/org/apache/synapse/handler/SynapseModule.java Mon Sep 17 04:10:10 2007
@@ -27,6 +27,7 @@
 import org.apache.neethi.Assertion;
 import org.apache.neethi.Policy;
 import org.apache.synapse.Constants;
+import org.apache.synapse.core.axis2.SynapseInitializationModule;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -35,9 +36,9 @@
 /**
  * This will be the Module class for the Synapse handler based mediations inside axis2 server. This
  * will just set the default system property of SYNAPSE_XML to the repository/conf/synapse.xml in
- * the axis2 servers repository and call the normal SynapseModule.init()
+ * the axis2 servers repository and call the normal SynapseInitializationModule.init()
  *
- * @see org.apache.synapse.core.axis2.SynapseModule
+ * @see org.apache.synapse.core.axis2.SynapseInitializationModule
  */
 public class SynapseModule implements Module {
 
@@ -47,16 +48,16 @@
     private static final Log log = LogFactory.getLog(SynapseModule.class);
 
     /**
      * Normal SynapseModule which initiates the Synapse
      */
-    private org.apache.synapse.core.axis2.SynapseModule module = null;
+    private SynapseInitializationModule initializationModule = null;
 
     /**
      * This method will call the normal initiation after setting the SYNAPSE_XML file to get from
      * the axis2 respository/conf folder
      * 
      * @param configurationContext - ConfigurationContext of the Axis2 env
      * @param axisModule - AxisModule describing handler module of Synapse
      * @throws AxisFault - incase of a failure in initiation
      */
     public void init(ConfigurationContext configurationContext,
@@ -66,69 +67,69 @@
                     getAxisConfiguration().getRepository().getPath() + "/conf/synapse.xml");
         }
         if (new File(System.getProperty(Constants.SYNAPSE_XML)).exists()) {
-            module = new org.apache.synapse.core.axis2.SynapseModule();
-            module.init(configurationContext, axisModule);
+            initializationModule = new org.apache.synapse.core.axis2.SynapseInitializationModule();
+            initializationModule.init(configurationContext, axisModule);
         } else {
-            handleException("Unable to initialize the Synapse module. Couldn't " +
+            handleException("Unable to initialize the Synapse initializationModule. Couldn't " +
                     "find the configuration file in the location "
                     + System.getProperty(Constants.SYNAPSE_XML));
         }
     }
 
     /**
      * Just do what the main SynapseModule tells you to do
      * 
      * @param axisDescription
      * @throws AxisFault
      */
     public void engageNotify(AxisDescription axisDescription) throws AxisFault {
-        if (module != null) {
-            module.engageNotify(axisDescription);
+        if (initializationModule != null) {
+            initializationModule.engageNotify(axisDescription);
         } else {
-            handleException("Couldn't find the module");
+            handleException("Couldn't find the initializationModule");
         }
     }
 
     /**
      * Just do what the main SynapseModule tells you to do
      * 
      * @param assertion
      * @return
      */
     public boolean canSupportAssertion(Assertion assertion) {
-        if (module != null) {
-            return module.canSupportAssertion(assertion);
+        if (initializationModule != null) {
+            return initializationModule.canSupportAssertion(assertion);
         } else {
             return false;
         }
     }
 
     /**
      * Just do what the main SynapseModule tells you to do
      * 
      * @param policy
      * @param axisDescription
      * @throws AxisFault
      */
     public void applyPolicy(Policy policy, AxisDescription axisDescription) throws AxisFault {
-        if (module != null) {
-            module.applyPolicy(policy, axisDescription);
+        if (initializationModule != null) {
+            initializationModule.applyPolicy(policy, axisDescription);
         } else {
-            handleException("Couldn't find the module");
+            handleException("Couldn't find the initializationModule");
         }
     }
 
     /**
      * Just do what the main SynapseModule tells you to do
      * 
      * @param configurationContext
      * @throws AxisFault
      */
     public void shutdown(ConfigurationContext configurationContext) throws AxisFault {
-        if (module != null) {
-            module.shutdown(configurationContext);
+        if (initializationModule != null) {
+            initializationModule.shutdown(configurationContext);
         } else {
-            handleException("Couldn't find the module");
+            handleException("Couldn't find the initializationModule");
         }
     }
 



---------------------------------------------------------------------
@@ -47,16 +48,16 @@
 
     /**
-     * Normal SynapseModule which initiates the Synapse
+     * Normal SynapseInitializationModule which initiates the Synapse
      */
@@ -47,16 +48,16 @@
      * 
      * @param configurationContext - ConfigurationContext of the Axis2 env
-     * @param axisModule - AxisModule describing handler module of Synapse
+     * @param axisModule - AxisModule describing handler initializationModule of Synapse
      * @throws AxisFault - incase of a failure in initiation
      */
@@ -66,69 +67,69 @@
 
     /**
-     * Just do what the main SynapseModule tells you to do
+     * Just do what the main SynapseInitializationModule tells you to do
      * 
      * @param axisDescription
@@ -66,69 +67,69 @@
 
     /**
-     * Just do what the main SynapseModule tells you to do
+     * Just do what the main SynapseInitializationModule tells you to do
      * 
      * @param assertion
@@ -66,69 +67,69 @@
 
     /**
-     * Just do what the main SynapseModule tells you to do
+     * Just do what the main SynapseInitializationModule tells you to do
      * 
      * @param policy
@@ -66,69 +67,69 @@
 
     /**
-     * Just do what the main SynapseModule tells you to do
+     * Just do what the main SynapseInitializationModule tells you to do
      * 
      * @param configurationContext
To unsubscribe, e-mail: synapse-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: synapse-dev-help@ws.apache.org